See `Details` for information on each deprecated function and suggested alternatives.
ggeye is deprecated: I no longer think it is good practice to design
monolithic functions that output ggplot objects; instead, it is more flexible
to design geoms and stats that can used within a complete ggplot
workflow. geom_eyeh offers a horizontal eye plot geom that can
be used instad of ggeye.
gather_lsmeans_samples is a deprecated alias for gather_emmeans_samples.
The new name (estimated marginal means) is more appropriate for Bayesian models than
the old name (least-squares means).